@@ -1,12 +1,14 @@
 package Imager::Font::FT2;
+use 5.006;
 use strict;
 use Imager;
 use Scalar::Util ();
-use vars qw($VERSION @ISA);
-@ISA = qw(Imager::Font);
+our @ISA = qw(Imager::Font);
+
+our $VERSION;
 
 BEGIN {
-  $VERSION = "0.95";
+  $VERSION = "1.001";
 
   require XSLoader;
   XSLoader::load('Imager::Font::FT2', $VERSION);
